==> Tplyr_0.4.4.tar.gz: Tplyr/tests/testthat/_snaps/layer.md <==
# `tplyr_layer` errors when no arguments provided

    The `parent` argument must be provided.

# type field can only contain one of 'count', 'desc', or 'shift'

    `type` must be one of "count", "desc", or "shift"

---

    `type` must be one of "count", "desc", or "shift"

---

    `type` must be one of "count", "desc", or "shift"

---

    `type` must be one of "count", "desc", or "shift"

# Parent must be a `tplyr_table`, `tplyr_layer`, or `tplyr_subgroup_layer`

    Must provide `tplyr_table`, `tplyr_layer`, or `tplyr_subgroup_layer` object from the `tplyr` package.

# `by` must me a string, a variable name, or multiple variables submitted using `dplyr::vars`

    Invalid input to `by`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `~list("a", "b")`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `~c("a", "b")`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `by`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `by`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

# `target_var` must me a string, a variable name, or multiple variables submitted using `dplyr::vars`

    Invalid input to `target_var`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `~list("a", "b")`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `~c("a", "b")`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `target_var`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `target_var`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

# `target_var` must exist in target dataset

    `target_var` variable `BadVar` does not exist in target dataset

---

    `target_var` variable `BadVar` does not exist in target dataset

# `by` varaibles must exist in the target dataset

    `by` variable `BadVars` does not exist in target dataset

---

    `by` variable `BadVars` does not exist in target dataset

# `where` must be programming logic (quosure of class 'call')

    The `where` parameter must contain subsetting logic (enter without quotes)

# Desc layers only accept numeric variables

    Target variable `supp` is not numeric. Target variables must be numeric for desc layers.

---

    Target variable `supp` is not numeric. Target variables must be numeric for desc layers.

---

    Target variable `supp` is not numeric. Target variables must be numeric for desc layers.

==> Tplyr_1.1.0.tar.gz: Tplyr/tests/testthat/_snaps/layer.md <==
# `tplyr_layer` errors when no arguments provided

    The `parent` argument must be provided.

# type field can only contain one of 'count', 'desc', or 'shift'

    `type` must be one of "count", "desc", or "shift"

---

    `type` must be one of "count", "desc", or "shift"

---

    `type` must be one of "count", "desc", or "shift"

---

    `type` must be one of "count", "desc", or "shift"

# Parent must be a `tplyr_table`, `tplyr_layer`, or `tplyr_subgroup_layer`

    Must provide `tplyr_table`, `tplyr_layer`, or `tplyr_subgroup_layer` object from the `tplyr` package.

# `by` must me a string, a variable name, or multiple variables submitted using `dplyr::vars`

    Invalid input to `by`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `~list("a", "b")`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `~c("a", "b")`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `by`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `by`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

# `target_var` must me a string, a variable name, or multiple variables submitted using `dplyr::vars`

    Invalid input to `target_var`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `~list("a", "b")`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `~c("a", "b")`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `target_var`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

---

    Invalid input to `target_var`. Submit either a string, a variable name, or multiple variable names using `dplyr::vars`.

# `target_var` must exist in target dataset

    `target_var` variable `BadVar` does not exist in target dataset

---

    `target_var` variable `BadVar` does not exist in target dataset

# `by` varaibles must exist in the target dataset

    `by` variable `BadVars` does not exist in target dataset

---

    `by` variable `BadVars` does not exist in target dataset

# `where` must be programming logic (quosure of class 'call')

    The `where` parameter must contain subsetting logic (enter without quotes)

# Desc layers only accept numeric variables

    i In index: 1.
    Caused by error:
    ! Target variable `supp` is not numeric. Target variables must be numeric for desc layers.

---

    i In index: 2.
    Caused by error:
    ! Target variable `supp` is not numeric. Target variables must be numeric for desc layers.

---

    i In index: 1.
    Caused by error:
    ! Target variable `supp` is not numeric. Target variables must be numeric for desc layers.
